@@ -1,5 +1,10 @@
 class LMQLModelRegistry: pass
 
+model_name_aliases = {
+    "chatgpt": "openai/gpt-3.5-turbo",
+    "gpt-4": "openai/gpt-4",
+}
+
 LMQLModelRegistry.registry = {}
 # instance of model clients in this process
 LMQLModelRegistry.clients = {}
